# Helper/YouOnMailer

an email package for the everyday projects

## Requirements

```js
    "require": {
        "php": ">=5.3.3",
        "swiftmailer/swiftmailer": "^5.0"
    }
```


## Creating a mailer instance 

```php
require("../vendor/autoload.php");

use Helper\YouOnMailer\Mailer\Mailer;
$mailer = new Mailer($hostOptions,$environment,$content);
```

Argument | Required | Description
------|------- |-------
$hostOptions| false | array for host stmp configuration (host, port, protocol, user , password )
$environment| false | environment in wich this package is used (Use development for access to logs and more detailed error messages)
$content| false | array or [EmailContent](#emailcontent-class) instance with the content of the email to send

### Mailer Class

- #### Variables
    - 
      Name | Type | Description
      ------|------- |-------
        transport | Swift_SmtpTransport | transport needed by swiftmailer
        host | string | email server endpoint
        hostPort | number | port number of email server
        hostProtocol | string | email server encryption (default: tls)
        hostUser | string | email server username
        hostPassword | string | email server username password
        emailContent | [EmailContent](#emailcontent-class) | Content of the email to send
        logger | Swift_Plugins_Loggers_ArrayLogger | Swiftmailer logger to track errors (only if env != 'production')
        env | string | environment of the package (ex: 'development', 'production')



- #### Methods
    -   
        Name | signature
        ------|-------
        setHost |setHost($host) 
        setHostPort |setHostPort($hostPort) 
        setHostProtocol |setHostProtocol($hostProtocol) 
        setHostUser |setHostUser($hostUser) 
        setHostPassword |setHostPassword($hostPassword) 
        setEmailContent |setEmailContent($content) 
        getEmailContent |getEmailContent() 
        setEnvironment |setEnvironment($environment) 
        sendEmail | sendEmail() 

### EmailContent Class

#### Creating a mailer instance 

```php
require("../vendor/autoload.php");

use Helper\YouOnMailer\Mailer\Content\EmailContent;
$content = new EmailContent($content);
```

Argument | Required | Description
------|------- |-------
$content| false | array or [EmailContent](#emailcontent-class) instance with the content of the email to send

#### if $content is an array then it has to have the values
Key | Required | Description
------| ------- | ----------
to | yes | array of emails where to send this email ( associative array where key is the email and value is the name)
from | yes | array of emails from where send this email ( associative array where key is the email and value is the name)
cc | no | array of emails to send in cc
bcc | no| array of emails to send in bcc
replyTo | no | array of emails where to reply to
subject | yes | subject of the email
message | maybe | email body as string ( You can either use this or use the view )
view |  maybe | email body as a template  ( You can either use this or use the message  )
attachments | no | array of filepaths for the attachments to send
attachmentsPath | no | string of the path to the attachments folder
viewsPath | no | If you use the view as body this is the path to the views folder
viewData | maybe | If you use the view as body you may need to pass some variables to the template ( this only accepts an array)
contentType | no | type of the email (default : 'text/html' )
max_file_size | no | max size of the attachment (default : 25MB)

#### class information

- #### Variables
    - 
      Name | Type | Description
      ------|------- |-------
        to | array | array of emails where to send this email ( associative array where key is the email and value is the name)
        from | array | array of emails from where send this email ( associative array where key is the email and value is the name)
        cc | array | array of emails to send in cc
        bcc | array| array of emails to send in bcc
        replyTo | array | array of emails where to reply to
        subject | string | subject of the email
        message | string | email body as string ( You can either use this or use the view )
        view |  string | email body as a template  ( You can either use this or use the message  )
        attachments | array | array of filepaths for the attachments to send
        attachmentsPath | string | string of the path to the attachments folder
        viewsPath | string | If you use the view as body this is the path to the views folder
        viewData | array | If you use the view as body you may need to pass some variables to the template ( this only accepts an array)
        contentType | string | type of the email (default : 'text/html' )
        MAX_FILE_SIZE | int | max size of the attachment (default : 25MB)

    ##### All variables are public (with the exception of MAX_FILE_SIZE ) so you can change there value freely

- #### Methods
    -   
        Name | signature
        ------|-------
        getMessage | getMessage()
        setMaxFileSize | setMaxFileSize($size)

## Examples


```php

require("../vendor/autoload.php");
define("ROOT",__DIR__);
define("VIEWSPATH", ROOT.DIRECTORY_SEPARATOR."views");
define("ATTACHMENTSPATH", ROOT.DIRECTORY_SEPARATOR."tmp");
define("ENVIRONMENT", "production"); //or production

use Helper\YouOnMailer\Mailer\Mailer;
use Helper\YouOnMailer\Mailer\Content\EmailContent;

$credentials = array(
    'host' => 'smtp.mailtrap.io',
    'port' => 2525,
    'protocol' => 'tls',
    'user' => '9c5536ccb80854',
    'password' => '0a7b94d216088d'
);
$content = new EmailContent(array(
    "to" => array('psilva@youongroup.com' => "Pedro Silva"),
    "from" => array('psilva@youongroup.com' => "YouOnMailer"),
    "subject" => "E-mail subject",
    "message" => "",
    "view" => "email/email.php", 
    "attachments" => array(
        "attachment.txt"
    ),
    "attachmentsPath" => ROOT.'/tmp',
    "viewsPath" => ROOT.'/views',
    "viewData" => array("name" => "Pedro Silva" , 
                        "email" => "psilva@youongroup.com", 
                        "feats"=> array("feat 1" , "feat 2" , "feat 3" , "feat 4"),
                        "date" => new \DateTime())
));


$mailer = new Mailer($credentials,ENVIRONMENT);
$mailer->setEmailContent($content);

/*or*/
/* 
 *  
 * $mailer = new Mailer($credentials,ENVIRONMENT,$content);
 *
 *
 */

try{ 
    $sended = $mailer->sendEmail();

    if($sended){
        echo "E-mail was successfully sended\n";
    }else{
        echo "Something went wrong when sending this email\n";
    }
}catch(\Exception $e){
    echo 'error occured while trying to send your message';
    echo "\n";
    echo $e->getMessage();
}

```


