<?php namespace Helper\YouOnMailer\Mailer\Content;


class EmailContent {

    public $subject;

    public $to = array();

    public $from = array();

    public $cc = array();

    public $bcc = array();

    public $replyTo = array();

    public $attachments = array();

    public $viewsPath = "";
    
    public $attachmentsPath = "";

    public $view = "";

    public $viewData = array();

    public $message = "";

    public $contentType = 'text/html';

    private $MAX_FILE_SIZE = 25000000; //in bytes


    public function __construct($data = null){
        if($data != null && $data instanceof EmailContent){
            $this->subject = $data->subject;
            $this->to = $data->to;
            $this->from =$data->from;
            $this->cc  = $data->cc;
            $this->bcc = $data->bcc;
            $this->replyTo = $data->replyTo;
            $this->view = $data->view;
            $this->attachments = $data->attachments;
            $this->viewsPath = $data->viewsPath;
            $this->attachmentsPath = $data->attachmentsPath;
            $this->message = $data->message;
            $this->viewData = $data->viewData;
            $this->contentType = $data->contentType;
            $this->MAX_FILE_SIZE = $data->MAX_FILE_SIZE;

        }else if(is_array($data)){
            $this->subject = isset($data["subject"]) ? $data["subject"]  : "";
            $this->to = isset($data["to"]) ? $data["to"]  : array();
            $this->from = isset($data["from"]) ? $data["from"]  : array();
            $this->cc  = isset($data["cc"]) ? $data["cc"]  : array();
            $this->bcc = isset($data["bcc"]) ? $data["bcc"]  : array();
            $this->replyTo = isset($data["replyTo"]) ? $data["replyTo"]  : array();
            $this->view  = isset($data["view"]) ? $data["view"]  : "";
            $this->attachments = isset($data["attachments"]) ? $data["attachments"]  : array();
            $this->viewsPath = isset($data["viewsPath"]) ? $data["viewsPath"]  : "";
            $this->attachmentsPath = isset($data["attachmentsPath"]) ? $data["attachmentsPath"]  : "";
            $this->message = isset($data["message"]) ? $data["message"]  : "";
            $this->viewData = isset($data["viewData"]) ? $data["viewData"]  : array();
            $this->contentType = isset($data["contentType"]) ? $data["contentType"]  : 'text/html';
            $this->MAX_FILE_SIZE = isset($data["max_file_size"]) ? $data["max_file_size"]  : 25000000;
        }
    }


    public function getMessage(){
        try{
            
            $body = $this->view != ""  ? $this->renderView() : $this->message;

            $message = \Swift_Message::newInstance()
                        ->setSubject($this->subject)
                        ->setFrom($this->from)
                        ->setTo($this->to)
                        ->setBody($body,$this->contentType);            
            
            if(count($this->cc)>0){
                $message->setCc($this->cc);
            }

            if(count($this->bcc) > 0){
                $message->setBcc($this->bcc);
            }

            if(count($this->replyTo) > 0){
                $message->setReplyTo($this->replyTo);
            }

            if(isset($this->attachments) && count($this->attachments) > 0){
                foreach($this->attachments as $attachment){
                    if(file_exists($this->attachmentsPath.'/'.$attachment)){
                        if(filesize($this->attachmentsPath.'/'.$attachment) <= $this->MAX_FILE_SIZE){
                            $message->attach(\Swift_Attachment::fromPath($this->attachmentsPath.'/'.$attachment));
                        }else{
                            throw new \Exception("Your attachments is bigger than MAX_FILE_SIZE($this->MAX_FILE_SIZE) and cannot be sended");
                        }
                    }else{
                        throw new \Exception("The file at ".$this->attachmentsPath.'/'.$attachment." does not exist");
                    }
                       
                }
            }
            
                        
            return $message;
        }catch(\Exception $e){
            throw $e;
        }
    }


    private function renderView(){


        ob_start();
        $i = extract($this->viewData);
        include($this->viewsPath.'/'.$this->view);
        $buffer = ob_get_contents();
        @ob_end_clean();


        return $buffer;
    }

    public function setMaxFileSize($size){
        $this->MAX_FILE_SIZE = $size;
    }

}