<?php namespace Helper\YouOnMailer\Mailer;

use Helper\YouOnMailer\Mailer\Content\EmailContent;
use Helper\YouOnMailer\Mailer\Exceptions\EmailNotSendedException;
class Mailer {

    private $transport;

    private $host;

    private $hostPort;

    private $hostProtocol = "tls";

    private $hostUser;

    private $hostPassword;

    public $emailContent = null;

    private $logger = null;

    private $env = "development";


    public function __construct($options = array(),$env = "development",$content = null){


        if(isset($options) && count($options) > 0){
            $this->host = isset($options["host"]) ? $options["host"] : "";
            $this->hostPort = isset($options["port"]) ? $options["port"] : "";
            $this->hostProtocol = isset($options["protocol"]) ? $options["protocol"] : "";
            $this->hostUser = isset($options["user"]) ? $options["user"] : "";
            $this->hostPassword = isset($options["password"]) ? $options["password"] : "";
        }

        if(isset($content)){
            $this->emailContent = new EmailContent($content); 
        }

        $this->env = $env;

        if($this->env != "production"){
            $this->logger = new \Swift_Plugins_Loggers_ArrayLogger();
        }
        
        
    }

    public function setHost($host){
        $this->host = $host;
    }

    public function setHostPort($hostPort){
        $this->hostPort = $hostPort;
    }

    public function setHostProtocol($hostProtocol){
        $this->hostProtocol = $hostProtocol;
    }

    public function setHostUser($hostUser){
        $this->hostUser = $hostUser;
    }

    public function setHostPassword($hostPassword){
        $this->hostPassword = $hostPassword;
    }

    public function setEmailContent($data){
       $this->emailContent = new EmailContent($data);
    }

    public function getEmailContent(){
        return $this->emailContent;
    }
    
    public function setEnvironment($env){
        $this->env = $env;
    }

    private function setTransport(){
        $this->transport = \Swift_SmtpTransport::newInstance($this->host, $this->hostPort,$this->hostProtocol)
        ->setUsername($this->hostUser)
        ->setPassword($this->hostPassword);
    }




    public function sendEmail(){

        $this->setTransport();
        $mailer = \Swift_Mailer::newInstance($this->transport);
        if($this->env != "production"){
            $mailer->registerPlugin(new \Swift_Plugins_LoggerPlugin($this->logger));
        }
        $message = $this->emailContent->getMessage();
        
        try {
            $failures = array();
            $response = $mailer->send($message,$failures);
            
            if($response){
                return true;
            }else{
                throw new EmailNotSendedException($failures,$this->env != "production" ? $this->logger->dump() : "");
            }

        }catch (EmailNotSendedException $e){
            throw $e;
        }catch (\Swift_TransportException $transporException){
            if($this->env != "production"){
                throw $transporException;
            }else{
                throw new \Exception("Connection could not be established with host");
            }
        }catch (\Exception $e3){
            throw $e3;
        }
    }
}